==> dde-launcher_5.0.14.orig.tar.xz: dde-launcher-5.0.14/translations/dde-launcher_ta.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ta" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>இசை</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>நிகழ்படம்</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation>கணினி</translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>நிறுத்து</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>உறுதிப்படுத்து</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open</source>
        <translation>திற</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>இசை</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>நிகழ்படம்</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation>விளையாட்டு</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation>கணினி</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>கணினி</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation>இசை</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock</source>
        <translation>பூட்டு</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>விடு பதிகை</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>மறுதொடக்கம்</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>தற்காலிகமாக நிறுத்தம் செய்தல்</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>நிறுத்து   </translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>கணினி</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>இசை</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>நிறுத்து   </translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>பூட்டு</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>விடு பதிகை</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>மறுதொடக்கம்</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>தற்காலிகமாக நிறுத்தம் செய்தல்</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>கணினி</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>இசை</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Manual</source>
        <translation>கைமுறை</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>அமைவுகள்</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation>மின்திறன்</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>நிறுத்து</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>உறுதிப்படுத்து</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>

==> dde-launcher_5.4.5.orig.tar.xz: dde-launcher-5.4.5/translations/dde-launcher_ta.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ta">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation>இசை</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>நிகழ்படம்</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation>கணினி</translation>
    </message>
    <message>
        <source>Games</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>நிறுத்து</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>உறுதிப்படுத்து</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation>திற</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music</source>
        <translation>இசை</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>நிகழ்படம்</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game</source>
        <translation>விளையாட்டு</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation>கணினி</translation>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation type="vanished">கணினி</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">இசை</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation type="vanished">பூட்டு</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation type="vanished">விடு பதிகை</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation type="vanished">மறுதொடக்கம்</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation type="vanished">தற்காலிகமாக நிறுத்தம் செய்தல்</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation type="vanished">நிறுத்து   </translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>கணினி</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>இசை</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>நிறுத்து   </translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>பூட்டு</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>விடு பதிகை</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>மறுதொடக்கம்</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>தற்காலிகமாக நிறுத்தம் செய்தல்</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Videos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation type="vanished">கணினி</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">இசை</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation type="vanished">கைமுறை</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">அமைவுகள்</translation>
    </message>
    <message>
        <source>Power</source>
        <translation type="vanished">மின்திறன்</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>நிறுத்து</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>உறுதிப்படுத்து</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
